Token.Shape
======

Shape
-----------

```{eval-rst}
.. autoclass:: miniworldmaker.tokens.shapes.Shape
   :members:
```

### Point


```{eval-rst}
.. autoclass:: miniworldmaker.tokens.shapes.Point
   :members:
```

### Circle


```{eval-rst}
.. autoclass:: miniworldmaker.tokens.shapes.Circle
   :members:
```

### Ellipse


```{eval-rst}
.. autoclass:: miniworldmaker.tokens.shapes.Ellipse
   :members:
```

### Line


```{eval-rst}
.. autoclass:: miniworldmaker.tokens.shapes.Line
   :members:
```

### Rectangle


```{eval-rst}
.. autoclass:: miniworldmaker.tokens.shapes.Rectangle
   :members:
```

### Polygon


```{eval-rst}
.. autoclass:: miniworldmaker.tokens.shapes.Polygon
   :members:
```
